@@ -24,17 +24,17 @@
 # @author
 #
 # \seealso{
-#   For conveniency, see functions @see "gstring" and @see "gcat".
+#   For convenience, see functions @see "gstring" and @see "gcat".
 # }
 #
 # @visibility public
 #*/###########################################################################
 setConstructorS3("GString", function(..., sep="") {
-  s <- paste(..., sep=sep);
+  s <- paste(..., sep=sep)
   if (length(s) > 1L) {
-    throw("Trying to coerce more than one character string to a GString, which is not supported.");
+    throw("Trying to coerce more than one character string to a GString, which is not supported.")
   }
-  extend(s, "GString");
+  extend(s, "GString")
 })
 
 
@@ -66,7 +66,7 @@ setConstructorS3("GString", function(..., sep="") {
 # }
 #*/###########################################################################
 setMethodS3("getRaw", "GString", function(object, ...) {
-  unclass(object);
+  unclass(object)
 })
 
 
@@ -98,8 +98,8 @@ setMethodS3("getRaw", "GString", function(object, ...) {
 #*/###########################################################################
 setMethodS3("print", "GString", function(x, ...) {
   # To please R CMD check.
-  object <- x;
-  print(as.character(object), ...);
+  object <- x
+  print(as.character(object), ...)
 })
 
 
@@ -131,8 +131,8 @@ setMethodS3("print", "GString", function(x, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getBuiltinPid", "GString", function(static, ...) {
-  pid <- Sys.getpid();
-  pid;
+  pid <- Sys.getpid()
+  pid
 }, static=TRUE)
 
 
@@ -165,19 +165,19 @@ setMethodS3("getBuiltinPid", "GString", function(static, ...) {
 setMethodS3("getBuiltinHostname", "GString", function(static, ...) {
   # 1. Try Sys.getenv()
   host <- Sys.getenv(c("HOST", "HOSTNAME", "COMPUTERNAME"))
-  host <- host[host != ""];
+  host <- host[host != ""]
 
   # 1. Try calling 'uname'
   if (length(host) == 0L) {
     tryCatch({
-      host <- readLines(pipe("/usr/bin/env uname -n"));
-      host <- host[host != ""];
+      host <- readLines(pipe("/usr/bin/env uname -n"))
+      host <- host[host != ""]
     }, error = function(ex) {})
   }
 
   if (length(host) == 0L)
-    host <- NA;
-  host[1L];
+    host <- NA
+  host[1L]
 }, static=TRUE)
 
 
@@ -209,25 +209,25 @@ setMethodS3("getBuiltinHostname", "GString", function(static, ...) {
 #*/###########################################################################
 setMethodS3("getBuiltinUsername", "GString", function(static, ...) {
   # 1. Try Sys.info(), which returns NULL if not implemented.
-  user <- Sys.info()["user"];
-  user <- user[user != "unknown"];
+  user <- Sys.info()["user"]
+  user <- user[user != "unknown"]
 
   # 2. Try Sys.getenv()
   if (length(user) == 0L) {
-    user <- Sys.getenv(c("USER", "USERNAME"));
-    user <- user[user != ""];
+    user <- Sys.getenv(c("USER", "USERNAME"))
+    user <- user[user != ""]
   }
 
   # 3. Try calling 'whoami'
   if (length(user) == 0L) {
     tryCatch({
       user <- readLines(pipe("/usr/bin/env whoami"))
-      user <- user[user != ""];
+      user <- user[user != ""]
     }, error = function(ex) {})
   }
   if (length(user) == 0L)
-    user <- NA;
-  user[1L];
+    user <- NA
+  user[1L]
 }, static=TRUE)
 
 
@@ -258,8 +258,8 @@ setMethodS3("getBuiltinUsername", "GString", function(static, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getBuiltinDate", "GString", function(static, format="%Y-%m-%d", ...) {
-  args <- list(Sys.time(), format=format);
-  do.call(base::format, args);
+  args <- list(Sys.time(), format=format)
+  do.call(base::format, args)
 }, static=TRUE)
 
 
@@ -290,8 +290,8 @@ setMethodS3("getBuiltinDate", "GString", function(static, format="%Y-%m-%d", ...
 # }
 #*/###########################################################################
 setMethodS3("getBuiltinTime", "GString", function(static, format="%H:%M:%S", ...) {
-  args <- list(Sys.time(), format=format);
-  do.call(base::format, args);
+  args <- list(Sys.time(), format=format)
+  do.call(base::format, args)
 }, static=TRUE)
 
 
@@ -322,8 +322,8 @@ setMethodS3("getBuiltinTime", "GString", function(static, format="%H:%M:%S", ...
 # }
 #*/###########################################################################
 setMethodS3("getBuiltinDatetime", "GString", function(static, format=NULL, ...) {
-  args <- list(Sys.time(), format=format);
-  do.call(base::format, args);
+  args <- list(Sys.time(), format=format)
+  do.call(base::format, args)
 }, static=TRUE)
 
 
@@ -353,7 +353,7 @@ setMethodS3("getBuiltinDatetime", "GString", function(static, format=NULL, ...)
 # }
 #*/###########################################################################
 setMethodS3("getBuiltinRversion", "GString", function(static, ...) {
-  getRversion();
+  getRversion()
 }, static=TRUE)
 
 
@@ -384,7 +384,7 @@ setMethodS3("getBuiltinRversion", "GString", function(static, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getBuiltinRhome", "GString", function(static, ...) {
-  R.home();
+  R.home()
 }, static=TRUE)
 
 
@@ -414,7 +414,7 @@ setMethodS3("getBuiltinRhome", "GString", function(static, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getBuiltinOs", "GString", function(static, ...) {
-  .Platform$OS.type;
+  .Platform$OS.type
 }, static=TRUE)
 
 
@@ -458,110 +458,110 @@ setMethodS3("getVariableValue", "GString", function(static, name, attributes="",
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'name':
   if (is.null(name)) {
-    throw("Argument 'name' is NULL.");
+    throw("Argument 'name' is NULL.")
   } else if (!is.character(name)) {
-    throw("Argument 'name' must be a character string: ", mode(name));
+    throw("Argument 'name' must be a character string: ", mode(name))
   }
 
   # Argument 'envir':
-  stopifnot(is.environment(envir));
+  .stop_if_not(is.environment(envir))
 
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Process attributes
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-  attrs <- strsplit(attributes, split=", ")[[1L]];
+  attrs <- strsplit(attributes, split=", ")[[1L]]
   if (length(attrs) > 0L) {
-    isSimpleAttr <- (regexpr("^[abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0-9._]+=.*$", attrs) == -1L);
-    simpleAttrs <- attrs[isSimpleAttr];
+    isSimpleAttr <- (regexpr("^[abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0-9._]+=.*$", attrs) == -1L)
+    simpleAttrs <- attrs[isSimpleAttr]
     if (length(simpleAttrs) == 0L)
-      simpleAttrs <- NULL;
-    attrs <- paste(attrs[!isSimpleAttr], collapse=", ");
-    attrs <- eval(parse(text=paste("list(", attrs, ")")));
+      simpleAttrs <- NULL
+    attrs <- paste(attrs[!isSimpleAttr], collapse=", ")
+    attrs <- eval(parse(text=paste("list(", attrs, ")")))
   } else {
-    attrs <- NULL;
-    simpleAttrs <- NULL;
+    attrs <- NULL
+    simpleAttrs <- NULL
   }
 
-  value <- NULL;
+  value <- NULL
   for (ww in where) {
     if (ww == "builtin") {
-      capitalizedName <- paste(toupper(substr(name, start=1L, stop=1L)), substr(name, start=2L, stop=nchar(name)), sep="");
-      builtInMethodName <- paste("getBuiltin", capitalizedName, sep="");
+      capitalizedName <- paste(toupper(substr(name, start=1L, stop=1L)), substr(name, start=2L, stop=nchar(name)), sep="")
+      builtInMethodName <- paste("getBuiltin", capitalizedName, sep="")
       tryCatch({
-        args <- list(static);
-        args <- c(args, attrs);
-        value <- do.call(builtInMethodName, args=args);
+        args <- list(static)
+        args <- c(args, attrs)
+        value <- do.call(builtInMethodName, args=args)
       }, error = function(ex) { })
     } else if (ww == "Sys.getenv") {
-      value <- Sys.getenv(name);
+      value <- Sys.getenv(name)
       if (nchar(value) == 0L)
-        value <- NULL;
+        value <- NULL
     } else if (ww == "getOption") {
-      value <- getOption(name);
+      value <- getOption(name)
     } else if (ww == "envir") {
       if (exists(name, envir=envir, inherits=inherits)) {
-        value <- get(name, envir=envir, inherits=inherits);
+        value <- get(name, envir=envir, inherits=inherits)
       }
     } else if (ww == "parent") {
-      envirL <- NULL;
-      n <- 0L;
+      envirL <- NULL
+      n <- 0L
       while (TRUE) {
-        n <- n + 1L;
-        envirP <- parent.frame(n=n);
+        n <- n + 1L
+        envirP <- parent.frame(n=n)
         if (identical(envirP, envirL))
-          break;
-        envirL <- envirP;
+          break
+        envirL <- envirP
         if (exists("...abcdef", envir=envirP, inherits=FALSE))
-          next;
+          next
         if (exists(name, envir=envirP, inherits=FALSE)) {
-          value <- get(name, envir=envirP, inherits=FALSE);
-          break;
+          value <- get(name, envir=envirP, inherits=FALSE)
+          break
         }
         if (identical(envir, .GlobalEnv))
-          break;
+          break
       }
     } else {
       if (exists(ww, mode="function")) {
         tryCatch({
-          args <- c(attrs, list(...));
-          value <- do.call(name, args=args);
+          args <- c(attrs, list(...))
+          value <- do.call(name, args=args)
         }, error = function(ex) {})
       } else {
-        throw("Unknown search location of variable '", name, "': ", ww);
+        throw("Unknown search location of variable '", name, "': ", ww)
       }
     }
 
     if (!is.null(value)) {
       tryCatch({
-        value <- as.character(value);
+        value <- as.character(value)
       }, error = function(ex) {
-        value <<- NA;
+        value <<- NA
       })
 
       # Apply simple attributes
       for (attr in simpleAttrs) {
         if (attr == "capitalize") {
           value <- paste(toupper(substring(value, first=1L, last=1L)),
-                                 substring(value, first=2L), sep="");
+                                 substring(value, first=2L), sep="")
         } else {
           tryCatch({
-            fcn <- get(attr, mode="function");
-            value <- fcn(value);
+            fcn <- get(attr, mode="function")
+            value <- fcn(value)
           }, error = function(ex) {})
         }
       }
 
       if (any(nchar(value) > 0L))
-        break;
+        break
     }
   } # for (ww in ...)
 
   if (is.null(value)) {
-    value <- missingValue;
+    value <- missingValue
   }
 
-  value;
+  value
 }, static=TRUE, private=TRUE)
 
 
@@ -593,90 +593,90 @@ setMethodS3("getVariableValue", "GString", function(static, name, attributes="",
 # }
 #*/###########################################################################
 setMethodS3("parse", "GString", function(object, ...) {
-  s <- getRaw(object);
+  s <- getRaw(object)
 
   # If there is no markup, then there is nothing to parse
   if (length(s) == 0L || !regexpr("${", s, fixed=TRUE) != -1L) {
-    return(list(text=s));
+    return(list(text=s))
   }
 
   # Parse the GString into a list of 'strings' intermixed with 'gstrings'.
-  parts <- list();
+  parts <- list()
 
   # Formats:
   # ${expression}
   # $[attribute,attribute,...,attribute]{expression}
 
   while(TRUE) {
-    pattern <- "^\\$(\\[.*\\]|)\\{([^\\}]*)\\}";
-    pos <- regexpr(pattern, s);
-    matchLen <- attr(pos, "match.length");
-    pos <- pos[1L];
+    pattern <- "^\\$(\\[.*\\]|)\\{([^\\}]*)\\}"
+    pos <- regexpr(pattern, s)
+    matchLen <- attr(pos, "match.length")
+    pos <- pos[1L]
     if (pos != -1L) {
-      text <- "";
+      text <- ""
     } else {
-      pattern <- "[^\\\\$]\\$(\\[.*\\]|)\\{([^\\}]*)\\}";
-      pos <- regexpr(pattern, s);
-      matchLen <- attr(pos, "match.length");
-      pos <- pos[1];
+      pattern <- "[^\\\\$]\\$(\\[.*\\]|)\\{([^\\}]*)\\}"
+      pos <- regexpr(pattern, s)
+      matchLen <- attr(pos, "match.length")
+      pos <- pos[1]
       if (pos != -1) {
-        text <- substr(s, start=1L, stop=pos);
-        text <- gsub("\\\\\\$", "$", text);
+        text <- substr(s, start=1L, stop=pos)
+        text <- gsub("\\\\\\$", "$", text)
       } else {
-        text <- s;
-        text <- gsub("\\\\\\$", "$", text);
-        parts <- c(parts, list(text=text));
-        break;
+        text <- s
+        text <- gsub("\\\\\\$", "$", text)
+        parts <- c(parts, list(text=text))
+        break
       }
     }
 
-    prefix <- list(text=text);
-    parts <- c(parts, prefix);
+    prefix <- list(text=text)
+    parts <- c(parts, prefix)
 
-    last <- pos + matchLen - 1L;
-    var <- substr(s, start=pos, stop=last);
+    last <- pos + matchLen - 1L
+    var <- substr(s, start=pos, stop=last)
 
-    attributes <- gsub(pattern, "\\1", var);
-    attributes <- gsub("^\\[", "", attributes);
-    attributes <- gsub("\\]$", "", attributes);
+    attributes <- gsub(pattern, "\\1", var)
+    attributes <- gsub("^\\[", "", attributes)
+    attributes <- gsub("\\]$", "", attributes)
 
-    name <- gsub(pattern, "\\2", var);
+    name <- gsub(pattern, "\\2", var)
 
-    searchReplace <- NULL;
-    patterns <- c("^[']([^']*)[']$", '^["]([^"]*)["]$');
+    searchReplace <- NULL
+    patterns <- c("^[']([^']*)[']$", '^["]([^"]*)["]$')
     if (all(sapply(patterns, FUN=regexpr, name) == -1L)) {
-      pattern <- "^(.*)/(.*)/(.*)";
+      pattern <- "^(.*)/(.*)/(.*)"
       if (regexpr(pattern, name) != -1L) {
-        searchPattern <- gsub(pattern, "\\2", name);
-        replacePattern <- gsub(pattern, "\\3", name);
-        name <- gsub(pattern, "\\1", name);
-        searchReplace <- list(search=searchPattern, replace=replacePattern);
+        searchPattern <- gsub(pattern, "\\2", name)
+        replacePattern <- gsub(pattern, "\\3", name)
+        name <- gsub(pattern, "\\1", name)
+        searchReplace <- list(search=searchPattern, replace=replacePattern)
       }
     } else {
       for (pattern in patterns) {
-        name <- gsub(pattern, "\\1", name);
+        name <- gsub(pattern, "\\1", name)
       }
     }
 
-    pattern <- "^`(.*)`";
-    isExpression <- (regexpr(pattern, name) != -1L);
+    pattern <- "^`(.*)`"
+    isExpression <- (regexpr(pattern, name) != -1L)
     if (isExpression) {
-      call <- gsub(pattern, "\\1", name);
-      part <- list(expression=list(call=call));
+      call <- gsub(pattern, "\\1", name)
+      part <- list(expression=list(call=call))
     } else {
-      part <- list(variable=list(name=name));
+      part <- list(variable=list(name=name))
     }
-    part[[1L]]$attributes <- attributes;
-    part[[1L]]$searchReplace <- searchReplace;
+    part[[1L]]$attributes <- attributes
+    part[[1L]]$searchReplace <- searchReplace
 
-    parts <- c(parts, part);
+    parts <- c(parts, part)
 
-    s <- substr(s, start=last+1L, stop=nchar(s));
+    s <- substr(s, start=last+1L, stop=nchar(s))
     if (nchar(s) == 0L)
-      break;
+      break
   } # while(TRUE)
 
-  parts;
+  parts
 }, private=TRUE)
 
 
@@ -709,48 +709,48 @@ setMethodS3("parse", "GString", function(object, ...) {
 #*/###########################################################################
 setMethodS3("evaluate", "GString", function(object, envir=parent.frame(), ...) {
   # Argument 'envir':
-  stopifnot(is.environment(envir));
+  .stop_if_not(is.environment(envir))
 
   # If there is no markup, then return alrady here.
-  s <- unclass(object);
+  s <- unclass(object)
   # If there is no markup, then there is nothing to parse
   if (length(s) == 0L || !regexpr("${", s, fixed=TRUE) != -1L) {
-    return(s);
+    return(s)
   }
 
-  parts <- parse(object, ...);
-  keys <- names(parts);
-  ...abcdef <- TRUE;
+  parts <- parse(object, ...)
+  keys <- names(parts)
+  ...abcdef <- TRUE
 
-  isVariable <- (keys == "variable");
+  isVariable <- (keys == "variable")
   for (kk in which(isVariable)) {
-    part <- parts[[kk]];
+    part <- parts[[kk]]
     value <- getVariableValue(object, name=part$name,
-                              attributes=part$attributes, envir=envir, ...);
+                              attributes=part$attributes, envir=envir, ...)
     if (!is.null(part$searchReplace))
       value <- gsub(part$searchReplace$search,
-                    part$searchReplace$replace, value);
-    parts[[kk]] <- value;
+                    part$searchReplace$replace, value)
+    parts[[kk]] <- value
   }
 
-  isExpression <- (keys == "expression");
+  isExpression <- (keys == "expression")
   for (kk in which(isExpression)) {
-    part <- parts[[kk]];
-    expr <- parse(text=part$call);
-    value <- eval(expr);
+    part <- parts[[kk]]
+    expr <- parse(text=part$call)
+    value <- eval(expr)
     if (!is.null(part$searchReplace))
       value <- gsub(part$searchReplace$search,
-                    part$searchReplace$replace, value);
-    parts[[kk]] <- value;
+                    part$searchReplace$replace, value)
+    parts[[kk]] <- value
   }
 
-  s <- "";
+  s <- ""
   for (kk in seq_along(parts)) {
-    part <- parts[[kk]];
-    s <- paste(s, part, sep="");
+    part <- parts[[kk]]
+    s <- paste(s, part, sep="")
   }
 
-  s;
+  s
 }, protected=TRUE) # evaluate()
 
 
@@ -780,46 +780,5 @@ setMethodS3("evaluate", "GString", function(object, envir=parent.frame(), ...) {
 # }
 #*/###########################################################################
 setMethodS3("as.character", "GString", function(x, envir=parent.frame(), ...) {
-  evaluate(x, envir=envir, ...);
+  evaluate(x, envir=envir, ...)
 })
-
-
-
-
-######################################################################
-# HISTORY:
-# 2013-12-13
-# o Added argument 'inherits' to evaluate() for GString.  Default
-#   is TRUE for backward compatibility.
-# 2013-02-18
-# o BUG FIX: evaluate(..., where="parent") for GString would result
-#   in an endless loop.
-# o Now it is possible to escape the sed-like search replace format
-#   for GString:s via quoting, e.g. ${'R.rsp/HttpDaemon/RspVersion'} .
-# 2013-02-14
-# o Added gstring() and gcat().
-# 2013-02-13
-# o Added evaluate() for GString.
-# 2011-11-19
-# o Now parse() and as.character() also handle "empty" GString:s.
-# 2011-11-15
-# o KNOWN ISSUES: as.character() is also finding objects of the
-#   local environment.
-# o SPEEDUP: Now as.character() and parse() for GString return
-#   faster if the string is a plain string without markup etc.
-#   This made as.character() about 10-15 times faster.
-# 2005-12-05
-# o BUG FIX: getVariableValue() would generate an error if a
-#   functions was detected. Now, NA is returned.
-# 2005-09-06
-# o BUG FIX of yesterdays patch. Forgot to extract the 'match.length'.
-# 2005-09-05
-# o Expected in parse() that regexpr() only returned one value, but
-#   sometimes it did return more and a warning was generated.
-# 2005-06-09
-# o Added print() to get rid of the class attributes.
-# o Made static method static.
-# 2005-06-08
-# o Added Rdoc comments to all methods.
-# o Created.
-######################################################################
