@@ -25,7 +25,7 @@
 #
 # \examples{\dontrun{
 #   onGarbageCollect(function(...) {
-#     message("The R garbage collector is running!");
+#     message("The R garbage collector is running!")
 #   })
 # }}
 #
@@ -34,22 +34,15 @@
 setMethodS3("onGarbageCollect", "default", function(fcn, action=c("prepend", "append", "replace"), ...) {
   # Argument 'fcn':
   if (!is.function(fcn)) {
-    throw("Argument 'fcn' is not a function: ", class(fcn)[1]);
+    throw("Argument 'fcn' is not a function: ", class(fcn)[1])
   }
 
   # Argument 'action':
-  action <- match.arg(action);
+  action <- match.arg(action)
 
-##  setHook("onGarbageCollect", fcn, action=action);
+##  setHook("onGarbageCollect", fcn, action=action)
 
-  dummyEnv <- new.env();
-  reg.finalizer(dummyEnv, fcn, onexit=FALSE);
-  invisible();
+  dummyEnv <- new.env()
+  reg.finalizer(dummyEnv, fcn, onexit=FALSE)
+  invisible()
 })
-
-
-############################################################################
-# HISTORY:
-# 2010-02-16
-# o Created.
-############################################################################
